@@ -145,6 +145,8 @@ class jac_value():
     def setup_value(self, value):
         if (isinstance(self.ctx, element)):
             self.is_element = self.ctx
+            if(self.parent._assign_mode):
+                self.is_element.save()
             self.ctx = self.ctx.context
         if value is not None:
             return value
