@@ -268,3 +268,19 @@ multi_breaks = \
         report nd.val;
     }
     """
+
+reffy_deref_check = \
+    """
+    node plain{has expected_answer;}
+
+    walker init {
+        nd = spawn here --> node::plain;
+        spawn here --> node::plain;
+
+        report *&-->[0] == *&-->[1];
+
+        actual_answer = -->[1];
+        nd.expected_answer = &-->[1];
+        report *&actual_answer == *nd.expected_answer;
+    }
+    """
